def to_int(s):
  try:
    return int(s)
  except:
    return 0
